Learn R Programming

allelic (version 0.1)

allelic.exact.test: Fast Unbiased Exact Allelic Test

Description

This is the implementation in R+C of a new association test described in "A fast, unbiased and exact allelic exact test for case-control association studies" (Submitted). It appears that in most cases the classical chi-square test used for testing for allelic association on genotype data is biased. Our test is unbiased, exact but fast throught careful optimization.

Usage

allelic.exact.test(d0,d1,d2,h0,h1,h2)

Arguments

d0
nb of first homozygous among cases
d1
nb of heterozygous among cases
d2
nb of second homozygous among cases
h0
nb of first homozygous among controls
h1
nb of heterozygous among controls
h2
nb of second homozygous among controls

Value

table is greater than TABLE\_OF\_LOG\_FACTORIALS\_SIZE, a C symbol defined in src/newallelic.c

See Also

chisq.test, fisher.test

Examples

Run this code
 allelic.exact.test(160,80,60,160,160,30)

Run the code above in your browser using DataLab